#  tests for astropy-healpix-0.5-py37hc8d92b1_0 (this is a generated file);
print('===== testing package: astropy-healpix-0.5-py37hc8d92b1_0 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---
# The test suite runs in <20 seconds so is worth running here to
# make sure there are no issues with the C/Cython extensions
import astropy_healpix
astropy_healpix.test()
#  --- run_test.py (end) ---

print('===== astropy-healpix-0.5-py37hc8d92b1_0 OK =====');
print("import: 'astropy_healpix'")
import astropy_healpix

